@@ -14,7 +14,7 @@ Usage::
     client: DLMClient = boto3.client("dlm")
     session_client: DLMClient = session.client("dlm")
 """
-from mypy_boto3_dlm.client import DLMClient as Client, DLMClient
+from mypy_boto3_dlm.client import DLMClient, DLMClient as Client
 
 
 __all__ = ("Client", "DLMClient")
